@@ -5,13 +5,14 @@
 # pylint: disable=cyclic-import
 # pyright: reportUnusedImport=false
 
-__version__ = "0.30.0"
+__version__ = "0.33.0"
 
 import sys
 import warnings
 
 from .command import AuditEventInfo, CmdContext, Command, Options
 from .pipeline import Pipeline
+from .prompt import Prompt
 from .pty_util import cbreak, cooked, raw
 from .result import Result, ResultError
 from .runner import PipeRunner, Runner
@@ -21,8 +22,8 @@ if sys.version_info[:3] in [(3, 10, 9), (3, 11, 1)]:
     # These releases have a known race condition.
     warnings.warn(  # pragma: no cover
         "Python 3.10.9 and Python 3.11.1 are unreliable with respect to "
-        "asyncio subprocesses. Consider a newer Python release: 3.10.10+ "
-        "or 3.11.2+. (https://github.com/python/cpython/issues/100133)",
+        + "asyncio subprocesses. Consider a newer Python release: 3.10.10+ "
+        + "or 3.11.2+. (https://github.com/python/cpython/issues/100133)",
         RuntimeWarning,
     )
 
@@ -44,6 +45,7 @@ __all__ = [
     "Command",
     "Options",
     "Pipeline",
+    "Prompt",
     "cbreak",
     "cooked",
     "raw",
