@@ -7,10 +7,12 @@
 
 import asyncio
 import collections.abc
+import contextlib
 import dataclasses
 import enum
 import io
 import os
+import re
 import shutil
 import signal
 from dataclasses import dataclass, field
@@ -36,6 +38,7 @@ from typing import (
 )
 
 import shellous
+from shellous.prompt import Prompt
 from shellous.pty_util import PtyAdapterOrBool
 from shellous.redirect import (
     STDIN_TYPES,
@@ -62,7 +65,7 @@ _UNSET = _UnsetEnum.UNSET
 _T = TypeVar("_T")
 Unset = Union[_T, _UnsetEnum]
 
-_RedirectT = Any  # type: ignore
+_RedirectT = Any
 _PreexecFnT = Optional[Callable[[], None]]
 
 
@@ -654,6 +657,45 @@ class Command(Generic[_RT]):
             Runner.run_command(self, _run_future=_run_future),
         )
 
+    @contextlib.asynccontextmanager
+    async def prompt(
+        self,
+        prompt: Union[str, list[str], re.Pattern[str], None] = None,
+        *,
+        timeout: Optional[float] = None,
+        normalize_newlines: bool = False,
+    ) -> AsyncIterator[Prompt]:
+        """Run command using the send/expect API.
+
+        This method should be called using `async with`. It returns a `Prompt`
+        object with send() and expect() methods.
+
+        You can optionally set a default `prompt`. This is used by `expect()`
+        when you don't provide another value.
+
+        Use the `timeout` parameter to set the default timeout for operations.
+
+        Set `normalize_newlines` to True to convert incoming CR and CR-LF to LF.
+        This conversion is done before matching with `expect()`. This option
+        does not affect strings sent with `send()`.
+        """
+        cmd = self.stdin(Redirect.CAPTURE).stdout(Redirect.CAPTURE)
+
+        cli = None
+        try:
+            async with Runner(cmd) as run:
+                cli = Prompt(
+                    run,
+                    default_prompt=prompt,
+                    default_timeout=timeout,
+                    normalize_newlines=normalize_newlines,
+                )
+                yield cli
+                cli.close()
+        finally:
+            if cli is not None:
+                cli._finish_()  # pyright: ignore[reportPrivateUsage]
+
     def __await__(self) -> "Generator[Any, None, _RT]":
         "Run process and return the standard output."
         return self.coro().__await__()
@@ -719,7 +761,7 @@ class Command(Generic[_RT]):
 
     def __ror__(self, lhs: StdinType) -> "Command[_RT]":
         "Bitwise or operator is used to build pipelines."
-        if isinstance(lhs, STDIN_TYPES):
+        if isinstance(lhs, STDIN_TYPES):  # pyright: ignore[reportUnnecessaryIsInstance]
             return self.stdin(lhs)
         return NotImplemented
 
