@@ -117,7 +117,7 @@ class _RunOptions:
             # If executable does not include an absolute/relative directory,
             # resolve it using PATH.
             executable = self.pos_args[0]
-            if not os.path.dirname(executable):  # type: ignore (path)
+            if not os.path.dirname(executable):
                 found_executable = _cmd.options.which(executable)
                 if found_executable is None:
                     raise FileNotFoundError(executable)
@@ -266,7 +266,7 @@ class _RunOptions:
         input_bytes = None
 
         if isinstance(input_, (bytes, bytearray)):
-            input_bytes = input_
+            input_bytes = bytes(input_)
         elif isinstance(input_, Path):
             stdin = open(input_, "rb")  # pylint: disable=consider-using-with
             self.open_fds.append(stdin)
@@ -419,6 +419,11 @@ class Runner:
         "Return name of process being run."
         return self.command.name
 
+    @property
+    def options(self) -> "shellous.Options":
+        "Return options for process being run."
+        return self.command.options
+
     @property
     def command(self) -> "shellous.Command[Any]":
         "Return the command being run."
@@ -441,8 +446,9 @@ class Runner:
             return None
         code = self._proc.returncode
         if code == _UNKNOWN_EXIT_CODE and self._last_signal is not None:
-            # Rarely after sending a SIGTERM, waitpid fails to locate the child
+            # After sending a signal, `waitpid` may fail to locate the child
             # process. In this case, map the status to the last signal we sent.
+            # For more on this, see https://github.com/python/cpython/issues/87744
             return -self._last_signal  # pylint: disable=invalid-unary-operand-type
         return code
 
@@ -451,10 +457,33 @@ class Runner:
         "Return True if the command was cancelled."
         return self._cancelled
 
-    def result(self) -> Result:
+    @property
+    def pty_fd(self) -> Optional[int]:
+        """The file descriptor used to communicate with the child PTY process.
+
+        Returns None if the process is not using a PTY.
+        """
+        pty_fds = self._options.pty_fds
+        if pty_fds is not None:
+            return pty_fds.parent_fd
+        return None
+
+    @property
+    def pty_eof(self) -> Optional[bytes]:
+        """Byte sequence used to indicate EOF when written to the PTY child.
+
+        Returns None if process is not using a PTY.
+        """
+        pty_fds = self._options.pty_fds
+        if pty_fds is not None:
+            return pty_fds.eof
+        return None
+
+    def result(self, *, check: bool = True) -> Result:
         "Check process exit code and raise a ResultError if necessary."
         code = self.returncode
-        assert code is not None
+        if code is None:
+            raise TypeError("Runner.result(): Process has not exited")
 
         result = Result(
             exit_code=code,
@@ -464,6 +493,9 @@ class Runner:
             encoding=self._options.encoding,
         )
 
+        if not check:
+            return result
+
         return check_result(
             result,
             self.command.options,
@@ -984,6 +1016,7 @@ class PipeRunner:
     _encoding: str
     _cancelled: bool = False
     _results: Optional[list[Union[BaseException, Result]]] = None
+    _pid: int = -1
 
     def __init__(self, pipe: "shellous.Pipeline[Any]", *, capturing: bool):
         """`capturing=True` indicates we are within an `async with` block and
@@ -1002,15 +1035,33 @@ class PipeRunner:
         "Return name of the pipeline."
         return self._pipe.name
 
-    def result(self) -> Result:
+    @property
+    def options(self) -> "shellous.Options":
+        """Return options for pipeline being run.
+
+        These are the options for the last command in the pipeline.
+        """
+        return self._pipe.options
+
+    @property
+    def pid(self) -> Optional[int]:
+        """Return the process ID for the first command in the pipeline.
+
+        The PID is only available when `capturing=True`.
+        """
+        if self._pid < 0:
+            return None
+        return self._pid
+
+    def result(self, *, check: bool = True) -> Result:
         "Return `Result` object for PipeRunner."
         assert self._results is not None
 
-        return check_result(
-            convert_result_list(self._results, self._cancelled),
-            self._pipe.options,
-            self._cancelled,
-        )
+        result = convert_result_list(self._results, self._cancelled)
+        if not check:
+            return result
+
+        return check_result(result, self._pipe.options, self._cancelled)
 
     def add_task(
         self,
@@ -1039,7 +1090,7 @@ class PipeRunner:
         self._tasks.clear()  # clear all tasks when done
 
     @log_method(LOG_DETAIL)
-    async def __aenter__(self):
+    async def __aenter__(self) -> "PipeRunner":
         "Set up redirections and launch pipeline."
         try:
             return await self._start()
@@ -1082,7 +1133,7 @@ class PipeRunner:
     @log_method(LOG_DETAIL)
     async def _start(self):
         "Set up redirection and launch pipeline."
-        open_fds = []
+        open_fds: list[int] = []
 
         try:
             stdin = None
@@ -1155,6 +1206,7 @@ class PipeRunner:
             last_ready.stdout,
             last_ready.stderr,
         )
+        self._pid = first_ready.pid
 
         return (stdin, stdout, stderr)
 
